/* -*- mode: C++ ; c-basic-offset: 2; indent-tabs-mode: nil -*- */

%include "std_vector.i"

%import "rovector.i"

%{
#include "nds_buffer.hh"

  using NDS::buffer;
%}

%define DOC_BUFFER
"The buffer class facilitates the storage of data and accompanying
meta data."
%enddef
%feature( "autodoc", DOC_BUFFER ) buffer;
class buffer
  : public channel
{
public:
  //---------------------------------------------------------------------
  /// \brief Type second portion of a gps time
  //---------------------------------------------------------------------
  typedef long gps_second_type;
  //---------------------------------------------------------------------
  /// \brief Type nano second portion of a gps time
  //---------------------------------------------------------------------
  typedef long gps_nanosecond_type;
  //---------------------------------------------------------------------
  /// \brief Type appropriate for length.
  //---------------------------------------------------------------------
  typedef size_t size_type;
  //---------------------------------------------------------------------
  /// \brief Storage type for the data.
  //---------------------------------------------------------------------
  typedef std::vector< unsigned char > data_type;

  static const gps_second_type GPS_INF = 1999999999;

  //---------------------------------------------------------------------
  /// \brief Retrieve the number of samples being stored
  ///
  /// \return
  ///     The number of samples being stored
  //---------------------------------------------------------------------
  %define DOC_NDS_BUFFER_SAMPLES
  "Return the number of samples being stored"
  %enddef
  %feature("autodoc", DOC_NDS_BUFFER_SAMPLES) Start;
  size_type Samples( ) const;

  //---------------------------------------------------------------------
  /// \brief Retrieve the GPS start second of the data
  ///
  /// \return
  ///     The GPS start second of the data
  //---------------------------------------------------------------------
  %define DOC_NDS_BUFFER_START
  "Return the GPS start second of the data"
  %enddef
  %feature("autodoc", DOC_NDS_BUFFER_START) Start;
  gps_second_type Start( ) const;

  //---------------------------------------------------------------------
  /// \brief Retrieve the GPS start nano second of the data
  ///
  /// \return
  ///     The GPS start nano second of the data
  //---------------------------------------------------------------------
  %define DOC_NDS_BUFFER_START_NANO
  "Return the GPS start nano second of the data"
  %enddef
  %feature("autodoc", DOC_NDS_BUFFER_START_NANO) Start;
  gps_nanosecond_type StartNano( ) const;

  //---------------------------------------------------------------------
  /// \brief Retrieve the GPS stop second of the data
  ///
  /// \return
  ///     The GPS stop second of the data
  //---------------------------------------------------------------------
  %define DOC_NDS_BUFFER_STOP
  "Return the GPS stop second of the data"
  %enddef
  %feature("autodoc", DOC_NDS_BUFFER_STOP) Start;
  gps_second_type Stop( ) const;
};
